@@ -11,9 +11,9 @@ from PySide6 import QtCore as qtc
 from PySide6 import QtNetwork as qtn
 from PySide6 import QtWebSockets as qtws
 
-from qtgql import slot
 from qtgql.gqltransport.core import EncodeAble, GqlEncoder, QueryPayload, T
-from qtgql.typingref import UNSET
+from qtgql.tools import slot
+from qtgql.utils.typingref import UNSET
 
 logger = logging.getLogger(__name__)
 
@@ -146,7 +146,7 @@ class GqlWsTransportClient(qtws.QWebSocket):
         valid."""
         return self.isValid() and self._connection_ack
 
-    def subscribe(self, handler: HandlerProto) -> None:
+    def execute(self, handler: HandlerProto) -> None:
         client_id = handler.message.id
         self.handlers[client_id] = handler
         if self.isValid():
@@ -154,9 +154,6 @@ class GqlWsTransportClient(qtws.QWebSocket):
         else:
             self.pending_messages.append(handler.message)
 
-    # this might be helpful in the future for handling single operations.
-    query = subscribe
-
     def run_subscription(self, message: GqlClientMessage) -> None:
         self.sendTextMessage(self.dumps(message))
 
